//
// Copyright 2002-2005 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Pdf for Java. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//

package samples.form;

import com.aspose.pdf.kit.*;
import java.awt.Rectangle;

//This demo shows how to fill the field through the specified field name
public class FieldAdding {
  //Set the test pdf file's path here:
  static String path = "./examples/resources/";

  public static void main(String[] args) {
    try {
      //open the document and create a FormEditor object
      FormEditor formEditor = new FormEditor(path + "fieldAdd.pdf",
                                             path + "added.pdf");
      //create a FormFieldFacade to specify visual attributes
      FormFieldFacade facade = new FormFieldFacade();
      formEditor.setFacade(facade);

      //add a button field with grey background and beveled border
      facade.setBackgroudColor(new java.awt.Color(0xCC, 0xCC, 0xCC));
      facade.setBorderStyle(FormFieldFacade.BDSTYLE_BEVELED);
      formEditor.addField(FormEditor.FLDTYP_BTNFLD, "button1", "OK", 1,
                          new Rectangle(265, 695, 100, 25));

      //add a text field with blue dashed border, green background, and red inverse text
      facade.setBorderColor(new java.awt.Color(0, 0, 255));
      facade.setBorderStyle(FormFieldFacade.BDSTYLE_DASHED);
      facade.setBorderWidth(FormFieldFacade.BDWIDTH_THICK);
      facade.setBackgroudColor(new java.awt.Color(0, 255, 0));
      facade.setAlignment(FormFieldFacade.ALIGN_CENTER);
      facade.setFont(FontStyle.TimesBoldItalic);
      facade.setTextColor(new java.awt.Color(255, 0, 0));
      facade.setFontSize(12);
      facade.setRotation(180);
      formEditor.addField(FormEditor.FLDTYP_TXTFLD, "text1", "This is a line", 1,
                          new Rectangle(215, 647, 200, 25));
      formEditor.resetFacade();

      //add a check box field with normal appearance
      formEditor.addField(FormEditor.FLDTYP_CHKBOX, "checkbox1", "On", 1,
                          new Rectangle(215, 601, 25, 25));
      //list box items
      formEditor.setItems(new String[] {"Music", "Sports", "Game"});
      //add a list box field with normal appearance
      formEditor.addField(FormEditor.FLDTYP_LIST, "list1", "Sports", 1,
                          new Rectangle(215, 555, 100, 18));
      //combo box items
      formEditor.setItems(new String[] {"America", "China", "England", "France"});
      //add a combo box field with normal appearance
      formEditor.addField(FormEditor.FLDTYP_COMBOBOX, "combobox1", "England", 1,
                          new Rectangle(215, 506, 100, 25));

      //radio button items
      formEditor.setItems(new String[] {"Male", "Female"});
      //add a radio button field with normal appearance
      formEditor.setRadioGap(30);
      formEditor.setRadioHoriz(true);
      formEditor.addField(FormEditor.FLDTYP_RADIOBTN, "radio1", "Female", 1,
                          new Rectangle(215, 460, 25, 25));

      //Close the document
      formEditor.close();

    }

    catch (Exception ex) {
      System.out.println(ex.toString());
    }
  }
}